@@ -35,6 +35,7 @@ struct Keys {
     access_token_secret: Option<String>,
 }
 
+type Term = Terminal<CrosstermBackend<Stdout>>;
 type TwitterResult = Result<(), TwitterErrors>;
 
 const MENU_TEXT: &str = "(l)ike | (r)eply | (n)ext | e(x)it";
@@ -153,18 +154,17 @@ fn get_key() -> char {
     }
 }
 
-async fn run_action(
-    tweet: &Tweet,
-    key: char,
-    token: &Token,
-    terminal: &mut Terminal<CrosstermBackend<Stdout>>,
-) -> String {
+fn clear_screen() {
+    stdout()
+        .execute(terminal::Clear(terminal::ClearType::All))
+        .unwrap()
+        .execute(MoveTo(0, 0))
+        .unwrap();
+}
+
+async fn run_action(tweet: &Tweet, key: char, token: &Token, terminal: &mut Term) -> String {
     if key == 'x' {
-        stdout()
-            .execute(terminal::Clear(terminal::ClearType::All))
-            .unwrap()
-            .execute(MoveTo(0, 0))
-            .unwrap();
+        clear_screen();
         exit(0);
     };
     if key == 'l' {
@@ -192,7 +192,7 @@ async fn run_action(
     }
 }
 
-fn draw(text_0: Vec<Spans>, text_1: Vec<Spans>, terminal: &mut Terminal<CrosstermBackend<Stdout>>) {
+fn draw(text_0: Vec<Spans>, text_1: Vec<Spans>, terminal: &mut Term) {
     terminal
         .draw(|f| {
             let layout = Layout::default()
@@ -259,4 +259,6 @@ async fn main() {
             );
         }
     }
+
+    clear_screen();
 }
